@@ -17,24 +17,32 @@
  */
 package org.apache.tez.dag.api;
 
+import java.io.IOException;
 import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Deque;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.Stack;
+import java.util.Objects;
 
 import org.apache.commons.collections4.BidiMap;
 import org.apache.commons.collections4.bidimap.DualLinkedHashBidiMap;
 import org.apache.hadoop.classification.InterfaceStability;
+import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.yarn.util.ConverterUtils;
 import org.apache.tez.client.CallerContext;
 import org.apache.tez.common.JavaOptsChecker;
+import org.apache.tez.common.TezUtils;
 import org.apache.tez.dag.api.Vertex.VertexExecutionContext;
 import org.apache.tez.dag.api.records.DAGProtos;
 import org.apache.tez.serviceplugins.api.ServicePluginsDescriptor;
@@ -66,22 +74,22 @@ import org.apache.tez.dag.api.records.DAGProtos.PlanVertexType;
 import org.apache.tez.dag.api.records.DAGProtos.VertexPlan;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Preconditions;
+import org.apache.tez.common.Preconditions;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
 
 /**
- * Top level entity that defines the DAG (Directed Acyclic Graph) representing 
- * the data flow graph. Consists of a set of Vertices and Edges connecting the 
- * vertices. Vertices represent transformations of data and edges represent 
+ * Top level entity that defines the DAG (Directed Acyclic Graph) representing
+ * the data flow graph. Consists of a set of Vertices and Edges connecting the
+ * vertices. Vertices represent transformations of data and edges represent
  * movement of data between vertices.
  */
 @Public
 public class DAG {
-  
+
   private static final Logger LOG = LoggerFactory.getLogger(DAG.class);
-  
+
   final BidiMap<String, Vertex> vertices =
       new DualLinkedHashBidiMap<String, Vertex>();
   final Set<Edge> edges = Sets.newHashSet();
@@ -99,8 +107,6 @@ public class DAG {
   private Map<String,String> dagConf = new HashMap<String, String>();
   private VertexExecutionContext defaultExecutionContext;
 
-  private Stack<String> topologicalVertexStack = new Stack<String>();
-
   private DAG(String name) {
     this.name = name;
   }
@@ -123,11 +129,11 @@ public class DAG {
    * @return {@link DAG}
    */
   public synchronized DAG addTaskLocalFiles(Map<String, LocalResource> localFiles) {
-    Preconditions.checkNotNull(localFiles);
+    Objects.requireNonNull(localFiles);
     TezCommonUtils.addAdditionalLocalResources(localFiles, commonTaskLocalFiles, "DAG " + getName());
     return this;
   }
-  
+
   public synchronized DAG addVertex(Vertex vertex) {
     if (vertices.containsKey(vertex.getName())) {
       throw new IllegalStateException(
@@ -140,18 +146,18 @@ public class DAG {
   public synchronized Vertex getVertex(String vertexName) {
     return vertices.get(vertexName);
   }
-  
+
   /**
    * One of the methods that can be used to provide information about required
    * Credentials when running on a secure cluster. A combination of this and
    * addURIsForCredentials should be used to specify information about all
    * credentials required by a DAG. AM specific credentials are not used when
    * executing a DAG.
-   * 
+   *
    * Set credentials which will be required to run this dag. This method can be
    * used if the client has already obtained some or all of the required
    * credentials.
-   * 
+   *
    * @param credentials Credentials for the DAG
    * @return {@link DAG}
    */
@@ -173,7 +179,7 @@ public class DAG {
    */
   @Deprecated
   public synchronized DAG setDAGInfo(String dagInfo) {
-    Preconditions.checkNotNull(dagInfo);
+    Objects.requireNonNull(dagInfo);
     this.dagInfo = dagInfo;
     return this;
   }
@@ -185,13 +191,13 @@ public class DAG {
    * @return {@link DAG}
    */
   public synchronized DAG setCallerContext(CallerContext callerContext) {
-    Preconditions.checkNotNull(callerContext);
+    Objects.requireNonNull(callerContext);
     this.callerContext = callerContext;
     return this;
   }
 
   /**
-   * Create a group of vertices that share a common output. This can be used to implement 
+   * Create a group of vertices that share a common output. This can be used to implement
    * unions efficiently.
    * @param name Name of the group.
    * @param members {@link Vertex} members of the group
@@ -238,27 +244,27 @@ public class DAG {
    * setCredentials should be used to specify information about all credentials
    * required by a DAG. AM specific credentials are not used when executing a
    * DAG.
-   * 
+   *
    * This method can be used to specify a list of URIs for which Credentials
    * need to be obtained so that the job can run. An incremental list of URIs
    * can be provided by making multiple calls to the method.
-   * 
+   *
    * Currently, @{link credentials} can only be fetched for HDFS and other
    * {@link org.apache.hadoop.fs.FileSystem} implementations that support
    * credentials.
-   * 
+   *
    * @param uris
    *          a list of {@link URI}s
    * @return {@link DAG}
    */
   public synchronized DAG addURIsForCredentials(Collection<URI> uris) {
-    Preconditions.checkNotNull(uris, "URIs cannot be null");
+    Objects.requireNonNull(uris, "URIs cannot be null");
     urisForCredentials.addAll(uris);
     return this;
   }
 
   /**
-   * 
+   *
    * @return an unmodifiable list representing the URIs for which credentials
    *         are required.
    */
@@ -266,7 +272,7 @@ public class DAG {
   public synchronized Collection<URI> getURIsForCredentials() {
     return Collections.unmodifiableCollection(urisForCredentials);
   }
-  
+
   @Private
   public synchronized Set<Vertex> getVertices() {
     return Collections.unmodifiableSet(this.vertices.values());
@@ -299,7 +305,7 @@ public class DAG {
     edges.add(edge);
     return this;
   }
-  
+
   /**
    * Add a {@link GroupInputEdge} to the DAG.
    * @param edge {@link GroupInputEdge}
@@ -323,7 +329,7 @@ public class DAG {
     VertexGroup av = edge.getInputVertexGroup();
     av.addOutputVertex(edge.getOutputVertex(), edge);
     groupInputEdges.add(edge);
-    
+
     // add new edge between members of VertexGroup and destVertex of the GroupInputEdge
     List<Edge> newEdges = Lists.newLinkedList();
     Vertex dstVertex = edge.getOutputVertex();
@@ -332,14 +338,14 @@ public class DAG {
       newEdges.add(Edge.create(member, dstVertex, edge.getEdgeProperty()));
     }
     dstVertex.addGroupInput(uv.getGroupName(), uv.getGroupInfo());
-    
+
     for (Edge e : newEdges) {
       addEdge(e);
     }
-    
+
     return this;
   }
-  
+
   /**
    * Get the DAG name
    * @return DAG name
@@ -374,6 +380,18 @@ public class DAG {
     return this;
   }
 
+  /**
+   * Set history log level for this DAG. This config overrides the default or one set at the session
+   * level.
+   *
+   * @param historyLogLevel The ATS history log level for this DAG.
+   *
+   * @return this DAG
+   */
+  public DAG setHistoryLogLevel(HistoryLogLevel historyLogLevel) {
+    return this.setConf(TezConfiguration.TEZ_HISTORY_LOGGING_LOGLEVEL, historyLogLevel.name());
+  }
+
   /**
    * Sets the default execution context for the DAG. This can be overridden at a per Vertex level.
    * See {@link org.apache.tez.dag.api.Vertex#setExecutionContext(VertexExecutionContext)}
@@ -416,7 +434,7 @@ public class DAG {
         newKnownTasksVertices.add(vertex);
       }
     }
-    
+
     // walk through all known source 1-1 edges and infer parallelism
     // add newly inferred vertices for consideration as known sources
     // the outer loop will run for every new level of inferring the parallelism
@@ -439,19 +457,19 @@ public class DAG {
         }
       }
     }
-    
+
     // check for inconsistency and errors
     for (Edge e : edges) {
       Vertex inputVertex = e.getInputVertex();
       Vertex outputVertex = e.getOutputVertex();
-      
+
       if (e.getEdgeProperty().getDataMovementType() == DataMovementType.ONE_TO_ONE) {
         if (inputVertex.getParallelism() != outputVertex.getParallelism()) {
           // both should be equal or equal to -1.
           if (outputVertex.getParallelism() != -1) {
             throw new TezUncheckedException(
                 "1-1 Edge. Destination vertex parallelism must match source vertex. "
-                + "Vertex: " + inputVertex.getName() + " does not match vertex: " 
+                + "Vertex: " + inputVertex.getName() + " does not match vertex: "
                 + outputVertex.getName());
           }
         }
@@ -510,7 +528,7 @@ public class DAG {
       }
     }
   }
-  
+
   // AnnotatedVertex is used by verify()
   private static class AnnotatedVertex {
     Vertex v;
@@ -552,11 +570,11 @@ public class DAG {
   }
 
   @VisibleForTesting
-  void verify(boolean restricted) throws IllegalStateException {
+  Deque<String> verify(boolean restricted) throws IllegalStateException {
     if (vertices.isEmpty()) {
       throw new IllegalStateException("Invalid dag containing 0 vertices");
     }
-    
+
     // check for valid vertices, duplicate vertex names,
     // and prepare for cycle detection
     Map<String, AnnotatedVertex> vertexMap = new HashMap<String, AnnotatedVertex>();
@@ -574,14 +592,14 @@ public class DAG {
     for (Edge e : edges) {
       // Construct structure for cycle detection
       Vertex inputVertex = e.getInputVertex();
-      Vertex outputVertex = e.getOutputVertex();      
+      Vertex outputVertex = e.getOutputVertex();
       List<Edge> edgeList = edgeMap.get(inputVertex);
       if (edgeList == null) {
         edgeList = new ArrayList<Edge>();
         edgeMap.put(inputVertex, edgeList);
       }
       edgeList.add(e);
-      
+
       // Construct map for Input name verification
       Set<String> inboundSet = inboundVertexMap.get(outputVertex);
       if (inboundSet == null) {
@@ -589,7 +607,7 @@ public class DAG {
         inboundVertexMap.put(outputVertex, inboundSet);
       }
       inboundSet.add(inputVertex.getName());
-      
+
       // Construct map for Output name verification
       Set<String> outboundSet = outboundVertexMap.get(inputVertex);
       if (outboundSet == null) {
@@ -601,7 +619,7 @@ public class DAG {
 
     // check input and output names don't collide with vertex names
     for (Vertex vertex : vertices.values()) {
-      for (RootInputLeafOutput<InputDescriptor, InputInitializerDescriptor> 
+      for (RootInputLeafOutput<InputDescriptor, InputInitializerDescriptor>
            input : vertex.getInputs()) {
         if (vertexMap.containsKey(input.getName())) {
           throw new IllegalStateException("Vertex: "
@@ -610,7 +628,7 @@ public class DAG {
               + input.getName());
         }
       }
-      for (RootInputLeafOutput<OutputDescriptor, OutputCommitterDescriptor> 
+      for (RootInputLeafOutput<OutputDescriptor, OutputCommitterDescriptor>
             output : vertex.getOutputs()) {
         if (vertexMap.containsKey(output.getName())) {
           throw new IllegalStateException("Vertex: "
@@ -624,7 +642,7 @@ public class DAG {
     // Check for valid InputNames
     for (Entry<Vertex, Set<String>> entry : inboundVertexMap.entrySet()) {
       Vertex vertex = entry.getKey();
-      for (RootInputLeafOutput<InputDescriptor, InputInitializerDescriptor> 
+      for (RootInputLeafOutput<InputDescriptor, InputInitializerDescriptor>
            input : vertex.getInputs()) {
         if (entry.getValue().contains(input.getName())) {
           throw new IllegalStateException("Vertex: "
@@ -638,7 +656,7 @@ public class DAG {
     // Check for valid OutputNames
     for (Entry<Vertex, Set<String>> entry : outboundVertexMap.entrySet()) {
       Vertex vertex = entry.getKey();
-      for (RootInputLeafOutput<OutputDescriptor, OutputCommitterDescriptor> 
+      for (RootInputLeafOutput<OutputDescriptor, OutputCommitterDescriptor>
             output : vertex.getOutputs()) {
         if (entry.getValue().contains(output.getName())) {
           throw new IllegalStateException("Vertex: "
@@ -648,28 +666,89 @@ public class DAG {
         }
       }
     }
-    
-    
+
+
     // Not checking for repeated input names / output names vertex names on the same vertex,
     // since we only allow 1 at the moment.
     // When additional inputs are supported, this can be chceked easily (and early)
     // within the addInput / addOutput call itself.
 
-    detectCycles(edgeMap, vertexMap);
-    
+    Deque<String> topologicalVertexStack = detectCycles(edgeMap, vertexMap);
+
     checkAndInferOneToOneParallelism();
 
     if (restricted) {
       for (Edge e : edges) {
-        if (e.getEdgeProperty().getDataSourceType() !=
-          DataSourceType.PERSISTED) {
+        DataSourceType dataSourceType = e.getEdgeProperty().getDataSourceType();
+        if (dataSourceType != DataSourceType.PERSISTED &&
+            dataSourceType != DataSourceType.EPHEMERAL) {
           throw new IllegalStateException(
             "Unsupported source type on edge. " + e);
         }
-        if (e.getEdgeProperty().getSchedulingType() !=
-          SchedulingType.SEQUENTIAL) {
-          throw new IllegalStateException(
-            "Unsupported scheduling type on edge. " + e);
+      }
+    }
+
+    // check for conflicts between dag level local resource and vertex level local resource
+
+
+    return topologicalVertexStack;
+  }
+
+  @VisibleForTesting
+  void verifyLocalResources(Configuration tezConf) {
+    for (Vertex v : vertices.values()) {
+      for (Map.Entry<String, LocalResource> localResource : v
+          .getTaskLocalFiles().entrySet()) {
+        String resourceName = localResource.getKey();
+        LocalResource resource = localResource.getValue();
+        if (commonTaskLocalFiles.containsKey(resourceName)
+            && !commonTaskLocalFiles.get(resourceName).equals(resource)) {
+          // Different for some reason. Compare size, and then eventually hash
+          try {
+
+            LocalResource commonLr = commonTaskLocalFiles.get(resourceName);
+            if (resource.getSize() != commonLr.getSize()) {
+              throw new IllegalStateException(
+                  "There is conflicting local resource (size mismatch) (" +
+                      resourceName
+                      + ") between dag local resource and vertex " +
+                      v.getName() + " local resource. "
+                      + "\nResource of dag : " +
+                      commonTaskLocalFiles.get(resourceName)
+                      + "\nResource of vertex: " + resource);
+            }
+
+            Path vertexResourcePath =
+                ConverterUtils.getPathFromYarnURL(resource.getResource());
+            Path commonResourcePath = ConverterUtils.getPathFromYarnURL(
+                commonLr.getResource());
+
+            byte[] vertexResourceSha = TezClientUtils
+                .getResourceSha(vertexResourcePath.toUri(), tezConf);
+            byte[] commonResourceSha = TezClientUtils
+                .getResourceSha(commonResourcePath.toUri(), tezConf);
+
+            if (!Arrays.equals(vertexResourceSha, commonResourceSha)) {
+              throw new IllegalStateException(
+                  "There is conflicting local resource (sha mismatch) (" +
+                      resourceName
+                      + ") between dag local resource and vertex " +
+                      v.getName() + " local resource. "
+                      + "\nResource of dag : " +
+                      commonTaskLocalFiles.get(resourceName)
+                      + "\nResource of vertex: " + resource);
+            }
+
+          } catch (URISyntaxException | IOException e) {
+            throw new RuntimeException(
+                "Failed while attempting to validate sha for conflicting resources (" +
+                    resourceName
+                    + ") between dag local resource and vertex " + v.getName() +
+                    " local resource. "
+                    + "\nResource of dag : " +
+                    commonTaskLocalFiles.get(resourceName)
+                    + "\nResource of vertex: " + resource);
+          }
         }
       }
     }
@@ -677,25 +756,30 @@ public class DAG {
 
   // Adaptation of Tarjan's algorithm for connected components.
   // http://en.wikipedia.org/wiki/Tarjan%27s_strongly_connected_components_algorithm
-  private void detectCycles(Map<Vertex, List<Edge>> edgeMap, Map<String, AnnotatedVertex> vertexMap)
+  private Deque<String> detectCycles(Map<Vertex, List<Edge>> edgeMap,
+      Map<String, AnnotatedVertex> vertexMap)
     throws IllegalStateException {
+    Deque<String> topologicalVertexStack = new LinkedList<String>();
     Integer nextIndex = 0; // boxed integer so it is passed by reference.
     Stack<AnnotatedVertex> stack = new Stack<DAG.AnnotatedVertex>();
     for (AnnotatedVertex av : vertexMap.values()) {
       if (av.index == -1) {
         assert stack.empty();
-        strongConnect(av, vertexMap, edgeMap, stack, nextIndex);
+        strongConnect(av, vertexMap, edgeMap, stack, nextIndex, topologicalVertexStack);
       }
     }
+    return topologicalVertexStack;
   }
 
   // part of Tarjan's algorithm for connected components.
   // http://en.wikipedia.org/wiki/Tarjan%27s_strongly_connected_components_algorithm
   private void strongConnect(
-    AnnotatedVertex av,
-    Map<String, AnnotatedVertex> vertexMap,
-    Map<Vertex, List<Edge>> edgeMap,
-    Stack<AnnotatedVertex> stack, Integer nextIndex) throws IllegalStateException {
+      AnnotatedVertex av,
+      Map<String, AnnotatedVertex> vertexMap,
+      Map<Vertex, List<Edge>> edgeMap,
+      Stack<AnnotatedVertex> stack,
+      Integer nextIndex,
+      Deque<String> topologicalVertexStack) throws IllegalStateException {
     av.index = nextIndex;
     av.lowlink = nextIndex;
     nextIndex++;
@@ -707,7 +791,7 @@ public class DAG {
       for (Edge e : edgeMap.get(av.v)) {
         AnnotatedVertex outVertex = vertexMap.get(e.getOutputVertex().getName());
         if (outVertex.index == -1) {
-          strongConnect(outVertex, vertexMap, edgeMap, stack, nextIndex);
+          strongConnect(outVertex, vertexMap, edgeMap, stack, nextIndex, topologicalVertexStack);
           av.lowlink = Math.min(av.lowlink, outVertex.lowlink);
         } else if (outVertex.onstack) {
           // strongly connected component detected, but we will wait till later so that the full cycle can be displayed.
@@ -751,16 +835,17 @@ public class DAG {
                            Map<String, LocalResource> tezJarResources, LocalResource binaryConfig,
                            boolean tezLrsAsArchive) {
     return createDag(tezConf, extraCredentials, tezJarResources, binaryConfig, tezLrsAsArchive,
-        null, null, null);
+        null, null);
   }
 
   // create protobuf message describing DAG
   @Private
   public synchronized DAGPlan createDag(Configuration tezConf, Credentials extraCredentials,
       Map<String, LocalResource> tezJarResources, LocalResource binaryConfig,
-      boolean tezLrsAsArchive, Map<String, String> additionalConfigs,
-      ServicePluginsDescriptor servicePluginsDescriptor, JavaOptsChecker javaOptsChecker) {
-    verify(true);
+      boolean tezLrsAsArchive, ServicePluginsDescriptor servicePluginsDescriptor,
+      JavaOptsChecker javaOptsChecker) {
+    Deque<String> topologicalVertexStack = verify(true);
+    verifyLocalResources(tezConf);
 
     DAGPlan.Builder dagBuilder = DAGPlan.newBuilder();
     dagBuilder.setName(this.name);
@@ -790,13 +875,13 @@ public class DAG {
           groupBuilder.addGroupMembers(v.getName());
         }
         groupBuilder.addAllOutputs(groupInfo.outputs);
-        for (Map.Entry<String, InputDescriptor> entry : 
+        for (Map.Entry<String, InputDescriptor> entry :
              groupInfo.edgeMergedInputs.entrySet()) {
           groupBuilder.addEdgeMergedInputs(
               PlanGroupInputEdgeInfo.newBuilder().setDestVertexName(entry.getKey()).
               setMergedInput(DagTypeConverters.convertToDAGPlan(entry.getValue())));
         }
-        dagBuilder.addVertexGroups(groupBuilder); 
+        dagBuilder.addVertexGroups(groupBuilder);
       }
     }
 
@@ -868,7 +953,7 @@ public class DAG {
           dagCredentials.addAll(dataSink.getCredentials());
         }
       }
-      
+
       VertexPlan.Builder vertexBuilder = VertexPlan.newBuilder();
       vertexBuilder.setName(vertex.getName());
       vertexBuilder.setType(PlanVertexType.NORMAL); // vertex type is implicitly NORMAL until  TEZ-46.
@@ -898,12 +983,7 @@ public class DAG {
 
       if (vertex.getConf()!= null && vertex.getConf().size() > 0) {
         ConfigurationProto.Builder confBuilder = ConfigurationProto.newBuilder();
-        for (Map.Entry<String, String> entry : vertex.getConf().entrySet()) {
-          PlanKeyValuePair.Builder keyValueBuilder = PlanKeyValuePair.newBuilder();
-          keyValueBuilder.setKey(entry.getKey());
-          keyValueBuilder.setValue(entry.getValue());
-          confBuilder.addConfKeyValues(keyValueBuilder);
-        }
+        TezUtils.populateConfProtoFromEntries(vertex.getConf().entrySet(), confBuilder);
         vertexBuilder.setVertexConf(confBuilder);
       }
 
@@ -962,7 +1042,7 @@ public class DAG {
           }
         }
       }
-      
+
       if (vertex.getVertexManagerPlugin() != null) {
         vertexBuilder.setVertexManagerPlugin(DagTypeConverters
             .convertToDAGPlan(vertex.getVertexManagerPlugin()));
@@ -998,36 +1078,36 @@ public class DAG {
       dagBuilder.addEdge(edgeBuilder);
     }
 
-
-    ConfigurationProto.Builder confProtoBuilder =
-        ConfigurationProto.newBuilder();
     if (dagAccessControls != null) {
-      Configuration aclConf = new Configuration(false);
-      dagAccessControls.serializeToConfiguration(aclConf);
-      Iterator<Entry<String, String>> aclConfIter = aclConf.iterator();
-      while (aclConfIter.hasNext()) {
-        Entry<String, String> entry = aclConfIter.next();
-        PlanKeyValuePair.Builder kvp = PlanKeyValuePair.newBuilder();
-        kvp.setKey(entry.getKey());
-        kvp.setValue(entry.getValue());
-        TezConfiguration.validateProperty(entry.getKey(), Scope.DAG);
-        confProtoBuilder.addConfKeyValues(kvp);
-      }
+      dagBuilder.setAclInfo(DagTypeConverters.convertDAGAccessControlsToProto(dagAccessControls));
     }
-    if (additionalConfigs != null && !additionalConfigs.isEmpty()) {
-      for (Entry<String, String> entry : additionalConfigs.entrySet()) {
-        PlanKeyValuePair.Builder kvp = PlanKeyValuePair.newBuilder();
-        kvp.setKey(entry.getKey());
-        kvp.setValue(entry.getValue());
-        TezConfiguration.validateProperty(entry.getKey(), Scope.DAG);
-        confProtoBuilder.addConfKeyValues(kvp);
-      }
+
+    ConfigurationProto.Builder confProtoBuilder = ConfigurationProto.newBuilder();
+    if (!this.dagConf.isEmpty()) {
+      TezUtils.populateConfProtoFromEntries(this.dagConf.entrySet(), confProtoBuilder);
     }
-    if (this.dagConf != null && !this.dagConf.isEmpty()) {
-      for (Entry<String, String> entry : this.dagConf.entrySet()) {
+    // Copy historyLogLevel from tezConf into dagConf if its not overridden in dagConf.
+    String logLevel = this.dagConf.get(TezConfiguration.TEZ_HISTORY_LOGGING_LOGLEVEL);
+    if (logLevel != null) {
+      // The config is from dagConf, we have already added it to the proto above, just check if
+      // the value is valid.
+      if (!HistoryLogLevel.validateLogLevel(logLevel)) {
+        throw new IllegalArgumentException(
+            "Config: " + TezConfiguration.TEZ_HISTORY_LOGGING_LOGLEVEL +
+            " is set to invalid value: " + logLevel);
+      }
+    } else {
+      // Validate and set value from tezConf.
+      logLevel = tezConf.get(TezConfiguration.TEZ_HISTORY_LOGGING_LOGLEVEL);
+      if (logLevel != null) {
+        if (!HistoryLogLevel.validateLogLevel(logLevel)) {
+          throw new IllegalArgumentException(
+              "Config: " + TezConfiguration.TEZ_HISTORY_LOGGING_LOGLEVEL +
+              " is set to invalid value: " + logLevel);
+        }
         PlanKeyValuePair.Builder kvp = PlanKeyValuePair.newBuilder();
-        kvp.setKey(entry.getKey());
-        kvp.setValue(entry.getValue());
+        kvp.setKey(TezConfiguration.TEZ_HISTORY_LOGGING_LOGLEVEL);
+        kvp.setValue(logLevel);
         confProtoBuilder.addConfKeyValues(kvp);
       }
     }
@@ -1037,7 +1117,7 @@ public class DAG {
       dagBuilder.setCredentialsBinary(DagTypeConverters.convertCredentialsToProto(dagCredentials));
       TezCommonUtils.logCredentials(LOG, dagCredentials, "dag");
     }
-    
+
     return dagBuilder.build();
   }
 
