@@ -46,6 +46,7 @@ import org.apache.hadoop.yarn.exceptions.YarnException;
 import org.apache.tez.client.FrameworkClient;
 import org.apache.tez.common.counters.TezCounters;
 import org.apache.tez.dag.api.DAGNotRunningException;
+import org.apache.tez.dag.api.NoCurrentDAGException;
 import org.apache.tez.dag.api.TezConfiguration;
 import org.apache.tez.dag.api.TezException;
 import org.apache.tez.dag.api.TezUncheckedException;
@@ -408,6 +409,15 @@ public class DAGClientImpl extends DAGClient {
     } catch (ApplicationNotFoundException e) {
       LOG.info("DAG is no longer running - application not found by YARN", e);
       dagCompleted = true;
+    } catch (NoCurrentDAGException e) {
+      if (conf.getBoolean(TezConfiguration.DAG_RECOVERY_ENABLED,
+          TezConfiguration.DAG_RECOVERY_ENABLED_DEFAULT)) {
+        LOG.info("Got NoCurrentDAGException from AM, going on as recovery is enabled", e);
+      } else {
+        // if recovery is disabled, we're not expecting the DAG to be finished any time in the future
+        LOG.info("Got NoCurrentDAGException from AM, returning a failed DAG as recovery is disabled", e);
+        return dagLost();
+      }
     } catch (TezException e) {
       // can be either due to a n/w issue or due to AM completed.
       LOG.info("Cannot retrieve DAG Status due to TezException: {}", e.getMessage());
@@ -423,6 +433,14 @@ public class DAGClientImpl extends DAGClient {
     return dagStatus;
   }
 
+  private DAGStatus dagLost() {
+    DAGProtos.DAGStatusProto.Builder builder = DAGProtos.DAGStatusProto.newBuilder();
+    DAGStatus dagStatus = new DAGStatus(builder, DagStatusSource.AM);
+    builder.setState(DAGProtos.DAGStatusStateProto.DAG_FAILED);
+    builder.addAllDiagnostics(Collections.singleton(NoCurrentDAGException.MESSAGE_PREFIX));
+    return dagStatus;
+  }
+
   private VertexStatus getVertexStatusViaAM(String vertexName, Set<StatusGetOpts> statusOptions) throws
       IOException {
     VertexStatus vertexStatus = null;
@@ -435,9 +453,11 @@ public class DAGClientImpl extends DAGClient {
       LOG.info("DAG is no longer running - application not found by YARN", e);
       dagCompleted = true;
     } catch (TezException e) {
-      // can be either due to a n/w issue of due to AM completed.
+      // can be either due to a n/w issue or due to AM completed.
+      LOG.info("Cannot retrieve Vertex Status due to TezException: {}", e.getMessage());
     } catch (IOException e) {
       // can be either due to a n/w issue of due to AM completed.
+      LOG.info("Cannot retrieve Vertex Status due to IOException: {}", e.getMessage());
     }
 
     if (vertexStatus == null && !dagCompleted) {
@@ -455,10 +475,11 @@ public class DAGClientImpl extends DAGClient {
    */
   @VisibleForTesting
   protected DAGStatus getDAGStatusViaRM() throws TezException, IOException {
-    LOG.debug("GetDAGStatus via AM for app: {} dag:{}", appId, dagId);
+    LOG.debug("Get DAG status via framework client for app: {} dag: {}", appId, dagId);
     ApplicationReport appReport;
     try {
       appReport = frameworkClient.getApplicationReport(appId);
+      LOG.debug("Got appReport from framework client: {}", appReport);
     } catch (ApplicationNotFoundException e) {
       LOG.info("DAG is no longer running - application not found by YARN", e);
       throw new DAGNotRunningException(e);
