@@ -88,6 +88,8 @@ public class LocalClient extends FrameworkClient {
   private TezApiVersionInfo versionInfo = new TezApiVersionInfo();
   private volatile Throwable amFailException = null;
   private boolean isLocalWithoutNetwork;
+  private String amHost;
+  private int amPort;
 
   private static final String localModeDAGSchedulerClassName =
       "org.apache.tez.dag.app.dag.impl.DAGSchedulerNaturalOrderControlled";
@@ -204,6 +206,9 @@ public class LocalClient extends FrameworkClient {
     report.setProgress(dagAppMaster.getProgress());
     report.setAMRMToken(null);
 
+    this.amHost = dagAppMaster.getAppNMHost();
+    this.amPort = dagAppMaster.getRpcPort();
+
     return report;
   }
 
@@ -331,8 +336,17 @@ public class LocalClient extends FrameworkClient {
           // Prepare Environment
           Path logDir = new Path(userDir, "localmode-log-dir");
           Path localDir = new Path(userDir, "localmode-local-dir");
-          localFs.mkdirs(logDir);
-          localFs.mkdirs(localDir);
+
+          // fail fast if the local directories (on the paths that were used on HDFS) cannot be created
+          // in this case, user might want to choose a different staging path, which works on the local FS too
+          if (!localFs.mkdirs(logDir)) {
+            throw new IOException(
+                "Unable to create log directory, try to create it manually for further insights: " + logDir);
+          }
+          if (!localFs.mkdirs(localDir)) {
+            throw new IOException(
+                "Unable to create local directory, try to create it manually for further insights: " + localDir);
+          }
 
           UserGroupInformation.setConfiguration(conf);
           // Add session specific credentials to the AM credentials.
@@ -466,4 +480,14 @@ public class LocalClient extends FrameworkClient {
     }
     return super.shutdownSession(configuration, sessionAppId, ugi);
   }
+
+  @Override
+  public String getAmHost() {
+    return amHost;
+  }
+
+  @Override
+  public int getAmPort() {
+    return amPort;
+  }
 }
