@@ -61,6 +61,8 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.security.Credentials;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.apache.hadoop.yarn.api.ApplicationConstants;
+import org.apache.hadoop.yarn.api.records.Container;
+import org.apache.hadoop.yarn.api.records.ContainerId;
 import org.apache.hadoop.yarn.api.records.LocalResource;
 import org.apache.hadoop.yarn.event.EventHandler;
 import org.apache.hadoop.yarn.state.InvalidStateTransitonException;
@@ -248,6 +250,9 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
       new CommitCompletedTransition();
 
   private final MemoryMXBean memoryMXBean = ManagementFactory.getMemoryMXBean();
+  private final Set<ContainerId> containersUsedByCurrentDAG = new HashSet<>();
+  @VisibleForTesting
+  final Set<String> nodesUsedByCurrentDAG = new HashSet<>();
 
   protected static final
     StateMachineFactory<DAGImpl, DAGState, DAGEventType, DAGEvent>
@@ -1441,6 +1446,16 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
     dagCounters.findCounter(DAGCounter.AM_GC_TIME_MILLIS).setValue(totalDAGGCTime);
   }
   
+  @Override
+  public void incrementDagCounter(DAGCounter counter, int incrValue) {
+    dagCounters.findCounter(counter).increment(incrValue);
+  }
+
+  @Override
+  public void setDagCounter(DAGCounter counter, int setValue) {
+    dagCounters.findCounter(counter).setValue(setValue);
+  }
+
   private DAGState finished(DAGState finalState) {
     boolean dagError = false;
     try {
@@ -2542,4 +2557,39 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
     this.logDirs = logDirs;
     return this;
   }
+
+  @Override
+  public void onStart() {
+    startVertexServices();
+  }
+
+  @Override
+  public void onFinish() {
+    stopVertexServices();
+    updateCounters();
+  }
+
+  private void startVertexServices() {
+    for (Vertex v : getVertices().values()) {
+      v.startServices();
+    }
+  }
+
+  void stopVertexServices() {
+    for (Vertex v : getVertices().values()) {
+      v.stopServices();
+    }
+  }
+
+  @Override
+  public void addUsedContainer(Container container) {
+    containersUsedByCurrentDAG.add(container.getId());
+    nodesUsedByCurrentDAG.add(container.getNodeId().getHost());
+  }
+
+  private void updateCounters() {
+    setDagCounter(DAGCounter.TOTAL_CONTAINERS_USED, containersUsedByCurrentDAG.size());
+    setDagCounter(DAGCounter.NODE_USED_COUNT, nodesUsedByCurrentDAG.size());
+    setDagCounter(DAGCounter.NODE_TOTAL_COUNT, appContext.getTaskScheduler().getNumClusterNodes(true));
+  }
 }
