@@ -53,7 +53,7 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
   private TaskSchedulerContext real;
 
   private ExecutorService executorService;
-  
+
   /**
    * @param real the actual TaskSchedulerAppCallback
    * @param executorService the ExecutorService to be used to send these events.
@@ -70,6 +70,16 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
         container));
   }
 
+  @Override
+  public void containerAllocated(Container container) {
+    executorService.submit(new ContainerAllocatedCallable(real, container));
+  }
+
+  @Override
+  public void containerReused(Container container) {
+    executorService.submit(new ContainerReusedCallable(real, container));
+  }
+
   @Override
   public void containerCompleted(Object taskLastAllocated,
       ContainerStatus containerStatus) {
@@ -90,7 +100,7 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
 
   @Override
   public void appShutdownRequested() {
-    executorService.submit(new AppShudownRequestedCallable(real));
+    executorService.submit(new AppShutdownRequestedCallable(real));
   }
 
   @Override
@@ -116,7 +126,7 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
       throw new TezUncheckedException(e);
     }
   }
-  
+
   @Override
   public void preemptContainer(ContainerId containerId) {
     executorService.submit(new PreemptContainerCallable(real, containerId));
@@ -226,6 +236,38 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
     }
   }
 
+  static class ContainerAllocatedCallable extends TaskSchedulerContextCallbackBase
+      implements Callable<Void> {
+    private final Container container;
+
+    ContainerAllocatedCallable(TaskSchedulerContext app, Container container) {
+      super(app);
+      this.container = container;
+    }
+
+    @Override
+    public Void call() throws Exception {
+      app.containerAllocated(container);
+      return null;
+    }
+  }
+
+  static class ContainerReusedCallable extends TaskSchedulerContextCallbackBase
+      implements Callable<Void> {
+    private final Container container;
+
+    ContainerReusedCallable(TaskSchedulerContext app, Container container) {
+      super(app);
+      this.container = container;
+    }
+
+    @Override
+    public Void call() throws Exception {
+      app.containerReused(container);
+      return null;
+    }
+  }
+
   static class ContainerCompletedCallable extends TaskSchedulerContextCallbackBase
       implements Callable<Void> {
 
@@ -280,10 +322,10 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
     }
   }
 
-  static class AppShudownRequestedCallable extends TaskSchedulerContextCallbackBase
+  static class AppShutdownRequestedCallable extends TaskSchedulerContextCallbackBase
       implements Callable<Void> {
 
-    public AppShudownRequestedCallable(TaskSchedulerContext app) {
+    public AppShutdownRequestedCallable(TaskSchedulerContext app) {
       super(app);
     }
 
@@ -346,19 +388,19 @@ class TaskSchedulerContextImplWrapper implements TaskSchedulerContext {
   static class PreemptContainerCallable extends TaskSchedulerContextCallbackBase
       implements Callable<Void> {
     private final ContainerId containerId;
-    
+
     public PreemptContainerCallable(TaskSchedulerContext app, ContainerId id) {
       super(app);
       this.containerId = id;
     }
-    
+
     @Override
     public Void call() throws Exception {
       app.preemptContainer(containerId);
       return null;
     }
   }
-  
+
   static class GetProgressCallable extends TaskSchedulerContextCallbackBase
       implements Callable<Float> {
 
