@@ -104,6 +104,11 @@ public final class TezTestUtils {
       return Resource.newInstance(1024, 1);
     }
 
+    @Override
+    public int getVertexId() {
+      return 0;
+    }
+
     @Override
     public Resource getTotalAvailableResource() {
       return Resource.newInstance(10240, 10);
