@@ -32,6 +32,7 @@ import java.util.Random;
 import java.util.Set;
 
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.fs.CommonConfigurationKeysPublic;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileStatus;
@@ -113,6 +114,7 @@ public class TestRecovery {
       Configuration miniTezconf = new Configuration(conf);
       miniTezconf.setInt(YarnConfiguration.RM_AM_MAX_ATTEMPTS, 4);
       miniTezconf.set("fs.defaultFS", remoteFs.getUri().toString()); // use HDFS
+      miniTezconf.setLong(TezConfiguration.TEZ_AM_SLEEP_TIME_BEFORE_EXIT_MILLIS, 500);
       miniTezCluster.init(miniTezconf);
       miniTezCluster.start();
     }
@@ -165,13 +167,13 @@ public class TestRecovery {
                 ApplicationAttemptId.newInstance(appId, 1), null)),
             new SimpleShutdownCondition(TIMING.POST,
                 new VertexInitializedEvent(vertexId0, "Tokenizer", 0L, 0L, 0,
-                    "", null, initGeneratedEvents)),
+                    "", null, initGeneratedEvents, null)),
             new SimpleShutdownCondition(TIMING.POST,
                 new VertexInitializedEvent(vertexId1, "Summation", 0L, 0L, 0,
-                    "", null, null)),
+                    "", null, null, null)),
             new SimpleShutdownCondition(TIMING.POST,
                 new VertexInitializedEvent(vertexId2, "Sorter", 0L, 0L, 0, "",
-                    null, null)),
+                    null, null, null)),
 
             new SimpleShutdownCondition(TIMING.POST,
                 new VertexConfigurationDoneEvent(vertexId0, 0L, 2, null, null,
@@ -194,15 +196,15 @@ public class TestRecovery {
             new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
                 vertexId0, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
                 VertexState.SUCCEEDED, "", new TezCounters(),
-                new VertexStats(), new HashMap<String, Integer>())),
+                new VertexStats(), new HashMap<String, Integer>(), null)),
             new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
                 vertexId1, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
                 VertexState.SUCCEEDED, "", new TezCounters(),
-                new VertexStats(), new HashMap<String, Integer>())),
+                new VertexStats(), new HashMap<String, Integer>(), null)),
             new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
                 vertexId2, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
                 VertexState.SUCCEEDED, "", new TezCounters(),
-                new VertexStats(), new HashMap<String, Integer>())),
+                new VertexStats(), new HashMap<String, Integer>(), null)),
 
             new SimpleShutdownCondition(TIMING.POST, new TaskStartedEvent(
                 TezTaskID.getInstance(vertexId0, 0), "vertexName", 0L, 0L)),
@@ -301,6 +303,56 @@ public class TestRecovery {
 
   }
 
+  private void testOrderedWordCountMultipleRoundRecoverying(
+          RecoveryServiceWithEventHandlingHook.MultipleRoundShutdownCondition shutdownCondition,
+          boolean enableAutoParallelism, boolean generateSplitInClient) throws Exception {
+
+    for (int i=0; i<shutdownCondition.size(); i++) {
+      SimpleShutdownCondition condition = shutdownCondition.getSimpleShutdownCondition(i);
+      LOG.info("ShutdownCondition:" + condition.getEventType()
+              + ", event=" + condition.getEvent());
+    }
+
+    String inputDirStr = "/tmp/owc-input/";
+    Path inputDir = new Path(inputDirStr);
+    Path stagingDirPath = new Path("/tmp/owc-staging-dir");
+    remoteFs.mkdirs(inputDir);
+    remoteFs.mkdirs(stagingDirPath);
+    TestTezJobs.generateOrderedWordCountInput(inputDir, remoteFs);
+
+    String outputDirStr = "/tmp/owc-output/";
+    Path outputDir = new Path(outputDirStr);
+
+    TezConfiguration tezConf = new TezConfiguration(miniTezCluster.getConfig());
+    tezConf.setInt(TezConfiguration.TEZ_AM_MAX_APP_ATTEMPTS, 4);
+    tezConf.set(TezConfiguration.TEZ_AM_RECOVERY_SERVICE_CLASS,
+            RecoveryServiceWithEventHandlingHook.class.getName());
+    tezConf.set(
+            RecoveryServiceWithEventHandlingHook.AM_RECOVERY_SERVICE_HOOK_CLASS,
+            RecoveryServiceWithEventHandlingHook.MultipleRoundRecoveryEventHook.class.getName());
+    tezConf.set(RecoveryServiceWithEventHandlingHook.MultipleRoundRecoveryEventHook.MULTIPLE_ROUND_SHUTDOWN_CONDITION,
+            shutdownCondition.serialize());
+    tezConf.setBoolean(
+            ShuffleVertexManager.TEZ_SHUFFLE_VERTEX_MANAGER_ENABLE_AUTO_PARALLEL,
+            enableAutoParallelism);
+    tezConf.setBoolean(
+            RecoveryService.TEZ_TEST_RECOVERY_DRAIN_EVENTS_WHEN_STOPPED, false);
+    tezConf.set(TezConfiguration.TEZ_AM_STAGING_DIR, stagingDirPath.toString());
+    tezConf.setBoolean(
+            TezConfiguration.TEZ_AM_STAGING_SCRATCH_DATA_AUTO_DELETE, false);
+    OrderedWordCount job = new OrderedWordCount();
+    if (generateSplitInClient) {
+      Assert
+              .assertTrue("OrderedWordCount failed", job.run(tezConf, new String[]{
+                      "-generateSplitInClient", inputDirStr, outputDirStr, "5"}, null) == 0);
+    } else {
+      Assert
+              .assertTrue("OrderedWordCount failed", job.run(tezConf, new String[]{
+                      inputDirStr, outputDirStr, "5"}, null) == 0);
+    }
+    TestTezJobs.verifyOutput(outputDir, remoteFs);
+  }
+
   @Test(timeout = 1800000)
   public void testRecovery_HashJoin() throws Exception {
     ApplicationId appId = ApplicationId.newInstance(System.currentTimeMillis(),
@@ -326,11 +378,11 @@ public class TestRecovery {
             "dagName", new HashMap<String, Integer>(), ApplicationAttemptId
                 .newInstance(appId, 1), null)),
         new SimpleShutdownCondition(TIMING.POST, new VertexInitializedEvent(
-            vertexId0, "hashSide", 0L, 0L, 0, "", null, initGeneratedEvents)),
+            vertexId0, "hashSide", 0L, 0L, 0, "", null, initGeneratedEvents, null)),
         new SimpleShutdownCondition(TIMING.POST, new VertexInitializedEvent(
-            vertexId1, "streamingSide", 0L, 0L, 0, "", null, null)),
+            vertexId1, "streamingSide", 0L, 0L, 0, "", null, null, null)),
         new SimpleShutdownCondition(TIMING.POST, new VertexInitializedEvent(
-            vertexId2, "joiner", 0L, 0L, 0, "", null, null)),
+            vertexId2, "joiner", 0L, 0L, 0, "", null, null, null)),
 
         new SimpleShutdownCondition(TIMING.POST, new VertexStartedEvent(
             vertexId0, 0L, 0L)),
@@ -354,15 +406,15 @@ public class TestRecovery {
         new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
             vertexId0, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
             VertexState.SUCCEEDED, "", new TezCounters(), new VertexStats(),
-            new HashMap<String, Integer>())),
+            new HashMap<String, Integer>(), null)),
         new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
             vertexId1, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
             VertexState.SUCCEEDED, "", new TezCounters(), new VertexStats(),
-            new HashMap<String, Integer>())),
+            new HashMap<String, Integer>(), null)),
         new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
             vertexId2, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
             VertexState.SUCCEEDED, "", new TezCounters(), new VertexStats(),
-            new HashMap<String, Integer>())),
+            new HashMap<String, Integer>(), null)),
 
         new SimpleShutdownCondition(TIMING.POST, new TaskStartedEvent(TezTaskID
             .getInstance(vertexId0, 0), "vertexName", 0L, 0L)),
@@ -427,6 +479,9 @@ public class TestRecovery {
         RecoveryService.TEZ_TEST_RECOVERY_DRAIN_EVENTS_WHEN_STOPPED, false);
     tezConf.setBoolean(
         TezConfiguration.TEZ_AM_STAGING_SCRATCH_DATA_AUTO_DELETE, false);
+    tezConf.setInt(CommonConfigurationKeysPublic.IPC_CLIENT_CONNECT_MAX_RETRIES_KEY,0);
+    tezConf.setInt(CommonConfigurationKeysPublic.IPC_CLIENT_CONNECT_MAX_RETRIES_ON_SOCKET_TIMEOUTS_KEY, 0);
+    tezConf.setInt(CommonConfigurationKeysPublic.IPC_CLIENT_CONNECT_TIMEOUT_KEY,1000);
     tezConf.set(TezConfiguration.TEZ_AM_LOG_LEVEL, "INFO;org.apache.tez=DEBUG");
 
     hashJoinExample.setConf(tezConf);
@@ -501,4 +556,77 @@ public class TestRecovery {
     assertTrue(shutdownCondition.match(lastEvent));
   }
 
+  @Test(timeout = 1800000)
+  public void testTwoRoundsRecoverying() throws Exception {
+    ApplicationId appId = ApplicationId.newInstance(System.currentTimeMillis(),
+            1);
+    TezDAGID dagId = TezDAGID.getInstance(appId, 1);
+    TezVertexID vertexId0 = TezVertexID.getInstance(dagId, 0);
+    TezVertexID vertexId1 = TezVertexID.getInstance(dagId, 1);
+    TezVertexID vertexId2 = TezVertexID.getInstance(dagId, 2);
+    ContainerId containerId = ContainerId.newInstance(
+            ApplicationAttemptId.newInstance(appId, 1), 1);
+    NodeId nodeId = NodeId.newInstance("localhost", 10);
+    List<TezEvent> initGeneratedEvents = Lists.newArrayList(
+            new TezEvent(InputDataInformationEvent.createWithObjectPayload(0, new Object()), null));
+
+
+    List<SimpleShutdownCondition> shutdownConditions = Lists.newArrayList(
+
+            new SimpleShutdownCondition(TIMING.POST, new DAGInitializedEvent(
+                    dagId, 0L, "username", "dagName", null)),
+            new SimpleShutdownCondition(TIMING.POST, new DAGStartedEvent(dagId,
+                    0L, "username", "dagName")),
+            new SimpleShutdownCondition(TIMING.POST,
+                    new VertexInitializedEvent(vertexId0, "Tokenizer", 0L, 0L, 0,
+                            "", null, initGeneratedEvents, null)),
+            new SimpleShutdownCondition(TIMING.POST, new VertexStartedEvent(
+                    vertexId0, 0L, 0L)),
+            new SimpleShutdownCondition(TIMING.POST,
+                    new VertexConfigurationDoneEvent(vertexId0, 0L, 2, null, null,
+                            null, true)),
+            new SimpleShutdownCondition(TIMING.POST, new TaskStartedEvent(
+                    TezTaskID.getInstance(vertexId0, 0), "vertexName", 0L, 0L)),
+            new SimpleShutdownCondition(TIMING.POST,
+                    new TaskAttemptStartedEvent(TezTaskAttemptID.getInstance(
+                            TezTaskID.getInstance(vertexId0, 0), 0), "vertexName", 0L,
+                            containerId, nodeId, "", "", "")),
+            new SimpleShutdownCondition(TIMING.POST, new TaskFinishedEvent(
+                    TezTaskID.getInstance(vertexId0, 0), "vertexName", 0L, 0L,
+                    null, TaskState.SUCCEEDED, "", new TezCounters(), 0)),
+            new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
+                    vertexId0, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
+                    VertexState.SUCCEEDED, "", new TezCounters(),
+                    new VertexStats(), new HashMap<String, Integer>(), null)),
+            new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
+                    vertexId1, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
+                    VertexState.SUCCEEDED, "", new TezCounters(),
+                    new VertexStats(), new HashMap<String, Integer>(), null)),
+            new SimpleShutdownCondition(TIMING.POST, new VertexFinishedEvent(
+                    vertexId2, "vertexName", 1, 0L, 0L, 0L, 0L, 0L,
+                    VertexState.SUCCEEDED, "", new TezCounters(),
+                    new VertexStats(), new HashMap<String, Integer>(), null)),
+            new SimpleShutdownCondition(TIMING.POST, new DAGFinishedEvent(
+                    dagId, 0L, 0L, DAGState.SUCCEEDED, "", new TezCounters(),
+                    "username", "dagName", new HashMap<String, Integer>(),
+                    ApplicationAttemptId.newInstance(appId, 1), null))
+
+    );
+
+    Random rand = new Random();
+    for (int i = 0; i < shutdownConditions.size() - 1; i++) {
+      // randomly choose half of the test scenario to avoid
+      // timeout.
+      if (rand.nextDouble()<0.5) {
+        int nextSimpleConditionIndex = i + 1 + rand.nextInt(shutdownConditions.size() - i - 1);
+        if (nextSimpleConditionIndex == shutdownConditions.size() - 1) {
+          testOrderedWordCountMultipleRoundRecoverying(
+                  new RecoveryServiceWithEventHandlingHook.MultipleRoundShutdownCondition(
+                          Lists.newArrayList(shutdownConditions.get(i), shutdownConditions.get(nextSimpleConditionIndex)))
+                  , true,
+                  shutdownConditions.get(i).getHistoryEvent().getEventType() == HistoryEventType.VERTEX_STARTED);
+        }
+      }
+    }
+  }
 }
