@@ -41,11 +41,10 @@ public class TaskConcurrencyAnalyzer extends TezAnalyzerBase implements Analyzer
   private static final String[] headers = { "time", "vertexName", "concurrentTasksRunning" };
 
   private final CSVResult csvResult;
-  private final Configuration config;
 
   public TaskConcurrencyAnalyzer(Configuration conf) {
+    super(conf);
     this.csvResult = new CSVResult(headers);
-    this.config = conf;
   }
 
   private enum EventType {START, FINISH}
@@ -153,11 +152,6 @@ public class TaskConcurrencyAnalyzer extends TezAnalyzerBase implements Analyzer
         + "would be helpful in understanding whether any starvation was there or not.";
   }
 
-  @Override
-  public Configuration getConfiguration() {
-    return config;
-  }
-
   public static void main(String[] args) throws Exception {
     Configuration config = new Configuration();
     TaskConcurrencyAnalyzer analyzer = new TaskConcurrencyAnalyzer(config);
